@@ -10,14 +10,16 @@ mod tests {
                 pub arg_bool: bool
             }
 
-            pub trait FfiContract {
+            pub trait FfiContract : Send + Sync {
                 fn return_vec() -> Vec<u8>;
                 fn arg_vec(command: i32, data: Vec<u8>) -> i32;
                 fn arg_callback(command: i32, callback: Box<dyn FfiCallback>) -> i32;
+                fn return_callback() -> Box<dyn FfiCallback>;
             }
 
-            pub trait FfiCallback {
+            pub trait FfiCallback : Sync + Send {
                 fn callback_vec(&self, command: i32, data: Vec<u8>) -> i32;
+                fn test_self(self);
             }
         ";
 
@@ -69,6 +71,12 @@ mod tests {
             trait_desc[0].methods[2].return_type,
             AstType::Int("i32".to_string())
         );
+        assert_eq!(trait_desc[0].methods[3].name, "return_callback");
+        assert!(trait_desc[0].methods[3].args.is_empty());
+        assert_eq!(
+            trait_desc[0].methods[3].return_type,
+            AstType::Callback("FfiCallback".to_string())
+        );
 
         assert_eq!(trait_desc[1].name, "FfiCallback");
         assert_eq!(trait_desc[1].mod_name, "demo_mod");
@@ -89,5 +97,6 @@ mod tests {
             trait_desc[1].methods[0].args[1].ty,
             AstType::Vec(AstBaseType::Byte("u8".to_string()))
         );
+        assert_eq!(trait_desc[1].methods[1].name, "test_self")
     }
 }
