@@ -38,7 +38,12 @@ pub(crate) trait FileGenStrategy {
     fn gen_sdk_file(&self, mod_names: &[String]) -> Result<TokenStream>;
     fn quote_common_use_part(&self) -> Result<TokenStream>;
     fn quote_common_part(&self, trait_desc: &[TraitDesc]) -> Result<TokenStream>;
-    fn quote_callback_structures(&self, callback: &TraitDesc) -> Result<TokenStream>;
+    fn quote_for_all_cb(&self, callbacks: &[&TraitDesc]) -> Result<TokenStream>;
+    fn quote_callback_structures(
+        &self,
+        callback: &TraitDesc,
+        callbacks: &[&TraitDesc],
+    ) -> Result<TokenStream>;
     fn quote_for_structures(&self, struct_desc: &StructDesc) -> Result<TokenStream>;
     fn quote_method_sig(
         &self,
@@ -54,7 +59,13 @@ pub(crate) trait FileGenStrategy {
         args: &ArgDesc,
         callbacks: &[&TraitDesc],
     ) -> Result<TokenStream>;
-    fn quote_return_convert(&self, return_ty: &AstType, ret_name: &str) -> Result<TokenStream>;
+    fn quote_return_convert(
+        &self,
+        trait_desc: &TraitDesc,
+        callbacks: &[&TraitDesc],
+        return_ty: &AstType,
+        ret_name: &str,
+    ) -> Result<TokenStream>;
     fn ty_to_tokens(&self, ast_type: &AstType, direction: TypeDirection) -> Result<TokenStream>;
 }
 
@@ -64,7 +75,14 @@ pub(crate) trait CallbackGenStrategy {
         arg: &ArgDesc,
         trait_desc: &TraitDesc,
         callbacks: &[&TraitDesc],
-    ) -> TokenStream;
+    ) -> Result<TokenStream>;
+
+    fn return_convert(
+        &self,
+        ret_ty: &AstType,
+        trait_desc: &TraitDesc,
+        callbacks: &[&TraitDesc],
+    ) -> Result<TokenStream>;
 }
 
 impl<'a, T: FileGenStrategy + 'a> BridgeFileGen<'a, T> {
@@ -121,24 +139,19 @@ impl<'a, T: FileGenStrategy + 'a> BridgeFileGen<'a, T> {
         let callbacks = self
             .trait_descs
             .iter()
-            .filter(|desc| {
-                for imp in self.imp_desc.iter() {
-                    if imp.contract == desc.name {
-                        return false;
-                    }
-                }
-                true
-            })
+            .filter(|desc| desc.is_callback)
             .collect::<Vec<&TraitDesc>>();
 
         println!("callbacks is {:?}", &callbacks);
 
-        for struct_desc in self.struct_descs.iter() {
-            let tokens = self.strategy.quote_for_structures(struct_desc);
-            results.push(GenResult { result: tokens });
-        }
-
         for desc in self.trait_descs.iter() {
+            if desc.is_callback {
+                results.push(GenResult {
+                    result: self.strategy.quote_callback_structures(desc, &callbacks),
+                });
+                continue;
+            }
+
             let imps = self
                 .imp_desc
                 .iter()
@@ -156,15 +169,7 @@ impl<'a, T: FileGenStrategy + 'a> BridgeFileGen<'a, T> {
                     desc.name
                 ))
                 .into());
-            } else if imps.is_empty() {
-                println!(
-                    "You haven't impl the trait {}, so I guess it is a callback",
-                    desc.name
-                );
-                results.push(GenResult {
-                    result: self.strategy.quote_callback_structures(desc),
-                });
-            } else {
+            } else if imps.len() == 1 {
                 results.push(GenResult {
                     result: self.generate_for_one_trait(
                         desc,
@@ -174,6 +179,15 @@ impl<'a, T: FileGenStrategy + 'a> BridgeFileGen<'a, T> {
                     ),
                 });
             }
+
+        }
+
+        let tokens = self.strategy.quote_for_all_cb(&callbacks);
+        results.push(GenResult { result: tokens });
+
+        for struct_desc in self.struct_descs.iter() {
+            let tokens = self.strategy.quote_for_structures(struct_desc);
+            results.push(GenResult { result: tokens });
         }
 
         Ok(results)
@@ -312,9 +326,12 @@ impl<'a, T: FileGenStrategy + 'a> BridgeFileGen<'a, T> {
 
         let call_imp = self.quote_imp_call(&imp.name, method)?;
 
-        let return_handle = self
-            .strategy
-            .quote_return_convert(&method.return_type, "ret_value")?;
+        let return_handle = self.strategy.quote_return_convert(
+            trait_desc,
+            callbacks,
+            &method.return_type,
+            "result",
+        )?;
 
         // combine all the parts
         let result = quote! {
@@ -338,7 +355,7 @@ impl<'a, T: FileGenStrategy + 'a> BridgeFileGen<'a, T> {
             impl_name, &method.name
         );
 
-        let ret_name_str = "ret_value";
+        let ret_name_str = "result";
         let imp_fun_name = Ident::new(&method.name, Span::call_site());
         let ret_name_ident = Ident::new(ret_name_str, Span::call_site());
 
@@ -361,17 +378,14 @@ impl<'a, T: FileGenStrategy + 'a> BridgeFileGen<'a, T> {
         let imp_ident = Ident::new(impl_name, Span::call_site());
         let imp_call = match method.return_type.clone() {
             AstType::Void => quote! {
-                #imp_ident::#imp_fun_name(#rust_args_repeat);
+                let #ret_name_ident = #imp_ident::#imp_fun_name(#rust_args_repeat);
             },
-            AstType::Vec(AstBaseType::Byte(origin)) => {
-                if origin.contains("i8") {
-                    quote! {
-                        let mut #ret_name_ident = #imp_ident::#imp_fun_name(#rust_args_repeat);
-                    }
-                } else {
-                    quote! {
-                        let #ret_name_ident = #imp_ident::#imp_fun_name(#rust_args_repeat);
-                    }
+            AstType::Vec(AstBaseType::Byte(_))
+            | AstType::Vec(AstBaseType::Short(_))
+            | AstType::Vec(AstBaseType::Int(_))
+            | AstType::Vec(AstBaseType::Long(_)) => {
+                quote! {
+                    let mut #ret_name_ident = #imp_ident::#imp_fun_name(#rust_args_repeat);
                 }
             }
             AstType::Vec(_)
@@ -379,6 +393,7 @@ impl<'a, T: FileGenStrategy + 'a> BridgeFileGen<'a, T> {
             | AstType::Callback(_)
             | AstType::String
             | AstType::Byte(_)
+            | AstType::Short(_)
             | AstType::Int(_)
             | AstType::Long(_)
             | AstType::Float(_)
