@@ -15,7 +15,4 @@ pub mod java;
 extern crate lazy_static;
 
 #[macro_use] extern crate log;
-extern crate android_logger;
-
 use log::Level;
-use android_logger::Filter;
