@@ -1,7 +1,10 @@
-mod arg_cb;
 pub(crate) mod artifact;
+mod artifact_r2s;
+mod artifact_s2r;
 pub(crate) mod bridge;
 pub(crate) mod bridge_cb;
+mod bridge_r2s;
+mod bridge_s2r;
 mod callback;
 mod internal;
 mod manager;
